% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/correlationMatrix.R
\name{getGenoCorMatrix}
\alias{getGenoCorMatrix}
\title{Compute the genotype correlation matrix.}
\usage{
getGenoCorMatrix(lrsid, lchr, lpos, lrefall, pop, path = NULL, web = TRUE,
  pruning = TRUE, rthresh = 1)
}
\arguments{
\item{lrsid}{is a vector with the rs identifiers of the variants to extract}

\item{lchr}{is a vector with the chromosome number of the variants to extract}

\item{lpos}{is a vector with the physical position of the variants to extract}

\item{lrefall}{is a vector with the reference allele of the variant in the data.}

\item{pop}{is the 1000 Genomes code of the population in which data must be extracted}

\item{path}{is the path to the reference genotype file if locally downloaded (default is NULL)}

\item{web}{is a logical indicating whether to use web access or not (default is TRUE)}

\item{pruning}{is a logical indicating whether to prune the correlation matrix (default is TRUE)}

\item{rthresh}{is the threshold used to prune the correlation matrix (default is 1)}
}
\value{
The genotype correlation matrix of the specified variants
}
\description{
From a set of variants identified by the pair (chromosome, position), extract 
the SNPs from a reference panel in the specified population.
}
\details{
There are two ways of retrieving data from reference panel:

* Through web queries. Currently, this is hard-coded to access 1000 Genomes phase3 data hosted by
Brian Browning (author of BEAGLE):

\url{http://bochet.gcc.biostat.washington.edu/beagle/1000_Genomes_phase3_v5a/}

* Locally, if one has locally downloaded the reference panel files from the URL above
 
This implementation discards multi-allelic markers that have a "," in the
ALT column.

Position must be given in GRCh37 genome build.

The \code{pop} can be any of: ACB, ASW, BEB, CDX, CEU, CHB, CHS, CLM, ESN,
FIN, GBR, GIH, GWD, IBS, ITU, JPT, KHV, LWK, MSL, MXL, PEL, PJL, PUR, STU,
TSI, YRI. It can also be any super-population: AFR, AMR, EAS, EUR, SAS.

Then, code additively the genotype and modify the additively coded allele if 
reference alleles differ between data and reference panel
and finally compute the correlation matrix. Note that, by default, one SNP
in each pair with a correlation coefficient equal to 1 is removed.
}
\examples{

ids = c("rs4841662", "rs34311866")
chrom <- c(8, 4)
phys_pos <- c(11843758, 951947)
refall <- c("A", "T")
cor_matrix <- getGenoCorMatrix(lrsid = ids, lchr = chrom, lpos = phys_pos, 
                               lrefall = refall, pop = "EUR")

}
